RegistryManager class

The central repository used by distributed Registry instances.

Constructors

RegistryManager({Duration timeout = const Duration(seconds: 5)})
Create a new registry managed by the created RegistryManager.

Properties

commandPort → SendPort
The command port receiving commands for the registry manager.
no setter
hashCode → int
The hash code for this object.
no setterinherited
registry → Registry
Get a registry backed by this manager.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Shut down the registry service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited